from .fake import mpath_dmp
from .scsiid_mapper import ScsiIdObj

class MultiObj(ScsiIdObj):
    """This class represents a multipath object.

    Given this kind of object is dependent on other devices,
    it is wise to make sure the _slaves field contains a reference
    to the underlying object devices or this object is part of other
    objects taking care of this.
    """

    def __init__(self, base_obj, start=True):
        self._base_obj = base_obj
        self._path = None
        self._active = False
        self._slaves = None  # Not used at present
        if start:
            self._start()

    @property
    def path(self):
        """The main entry when multipath is used for the wwid device"""
        return self._path

    @property
    def scsi_id(self):
        """ SCSI ID, serial or WWID """
        return self._base_obj.scsi_id

    def set_persistent(self):
        self._base_obj.set_persistent()

    def close(self):
        self._stop()

        self._base_obj.close()

    def rescan(self):
        self._base_obj.rescan()

        self._refresh()

    def _start(self):
        path, slaves = self._start_mpath()
        self._path = path
        self._slaves = slaves
        self._active = True

    def _stop(self):
        self._stop_mpath()
        self._active = False
        self._path = None

    def _refresh(self):
        pass

    def _dump(self):
        pass

    def _start_mpath(self):
        mpath_dmp.refresh(self.scsi_id)
        return ("/dev/mapper/{}".format(self.scsi_id), None)

    def _stop_mpath(self):
        mpath_dmp.reset(self.scsi_id)
