"""
Storage device transport handler
"""
from .dispatcher import Dispatcher
from .blockprovider import BlockProviderException
from .scsiid_mapper import ScsiIdMapper

class TransportException(Exception):
    """
    General trasport exception type.
    Errors are returned as JSON formatted strings
    """
    pass


class Transport(object):
    """
    Transport manager class.
    """

    @staticmethod
    def get_block(configuration, rescan=False):
        """
        Create a block transport from the given device configuration.
        """
        if "provider" not in configuration:
            raise TransportException("No transport provider specified")

        if not Dispatcher.supported(configuration["provider"]):
            raise TransportException("Unsupported transport provider")

        try:
            device = Dispatcher.dispatch(configuration, rescan)
        except BlockProviderException, bpe:
            raise TransportException(bpe.message)
        return device
